==> com.liferay.roles.admin.web-3.0.72.jar: META-INF/resources/js/EditRoleAssignmentsManagementToolbarDefaultEventHandler.es.js <==
Liferay.Loader.define("roles-admin-web@3.0.72/js/EditRoleAssignmentsManagementToolbarDefaultEventHandler.es", ['module', 'exports', 'require', 'frontend-js-web'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = void 0;

  var _frontendJsWeb = require("frontend-js-web");

  function _typeof(obj) {
    "@babel/helpers - typeof";
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  function _classCallCheck(instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  }

  function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];descriptor.enumerable = descriptor.enumerable || false;descriptor.configurable = true;if ("value" in descriptor) descriptor.writable = true;Object.defineProperty(target, descriptor.key, descriptor);
    }
  }

  function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) _defineProperties(Constructor.prototype, protoProps);if (staticProps) _defineProperties(Constructor, staticProps);return Constructor;
  }

  function _possibleConstructorReturn(self, call) {
    if (call && (_typeof(call) === "object" || typeof call === "function")) {
      return call;
    }return _assertThisInitialized(self);
  }

  function _assertThisInitialized(self) {
    if (self === void 0) {
      throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
    }return self;
  }

  function _getPrototypeOf(o) {
    _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
      return o.__proto__ || Object.getPrototypeOf(o);
    };return _getPrototypeOf(o);
  }

  function _inherits(subClass, superClass) {
    if (typeof superClass !== "function" && superClass !== null) {
      throw new TypeError("Super expression must either be null or a function");
    }subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } });if (superClass) _setPrototypeOf(subClass, superClass);
  }

  function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
      o.__proto__ = p;return o;
    };return _setPrototypeOf(o, p);
  }

  var EditRoleAssignmentsManagementToolbarDefaultEventHandler = /*#__PURE__*/function (_DefaultEventHandler) {
    _inherits(EditRoleAssignmentsManagementToolbarDefaultEventHandler, _DefaultEventHandler);

    function EditRoleAssignmentsManagementToolbarDefaultEventHandler() {
      _classCallCheck(this, EditRoleAssignmentsManagementToolbarDefaultEventHandler);

      return _possibleConstructorReturn(this, _getPrototypeOf(EditRoleAssignmentsManagementToolbarDefaultEventHandler).apply(this, arguments));
    }

    _createClass(EditRoleAssignmentsManagementToolbarDefaultEventHandler, [{
      key: "addSegmentEntry",
      value: function addSegmentEntry(itemData) {
        window.sessionStorage.setItem(itemData.sessionKey, 'open');
        Liferay.Util.getTop().location.href = itemData.addSegmentEntryURL;
      }
    }]);

    return EditRoleAssignmentsManagementToolbarDefaultEventHandler;
  }(_frontendJsWeb.DefaultEventHandler);

  var _default = EditRoleAssignmentsManagementToolbarDefaultEventHandler;
  exports["default"] = _default;
  //# sourceMappingURL=EditRoleAssignmentsManagementToolbarDefaultEventHandler.es.js.map
});
//# sourceMappingURL=EditRoleAssignmentsManagementToolbarDefaultEventHandler.es.js.map

==> com.liferay.roles.admin.web-4.0.19.jar: META-INF/resources/js/EditRoleAssignmentsManagementToolbarDefaultEventHandler.es.js <==
Liferay.Loader.define("roles-admin-web@4.0.19/js/EditRoleAssignmentsManagementToolbarDefaultEventHandler.es", ['module', 'exports', 'require', 'frontend-js-web'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = void 0;

  var _frontendJsWeb = require("frontend-js-web");

  function _typeof(obj) {
    "@babel/helpers - typeof";
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  function _classCallCheck(instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  }

  function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];descriptor.enumerable = descriptor.enumerable || false;descriptor.configurable = true;if ("value" in descriptor) descriptor.writable = true;Object.defineProperty(target, descriptor.key, descriptor);
    }
  }

  function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) _defineProperties(Constructor.prototype, protoProps);if (staticProps) _defineProperties(Constructor, staticProps);return Constructor;
  }

  function _possibleConstructorReturn(self, call) {
    if (call && (_typeof(call) === "object" || typeof call === "function")) {
      return call;
    }return _assertThisInitialized(self);
  }

  function _assertThisInitialized(self) {
    if (self === void 0) {
      throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
    }return self;
  }

  function _getPrototypeOf(o) {
    _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
      return o.__proto__ || Object.getPrototypeOf(o);
    };return _getPrototypeOf(o);
  }

  function _inherits(subClass, superClass) {
    if (typeof superClass !== "function" && superClass !== null) {
      throw new TypeError("Super expression must either be null or a function");
    }subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } });if (superClass) _setPrototypeOf(subClass, superClass);
  }

  function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
      o.__proto__ = p;return o;
    };return _setPrototypeOf(o, p);
  }

  var EditRoleAssignmentsManagementToolbarDefaultEventHandler =
  /*#__PURE__*/
  function (_DefaultEventHandler) {
    _inherits(EditRoleAssignmentsManagementToolbarDefaultEventHandler, _DefaultEventHandler);

    function EditRoleAssignmentsManagementToolbarDefaultEventHandler() {
      _classCallCheck(this, EditRoleAssignmentsManagementToolbarDefaultEventHandler);

      return _possibleConstructorReturn(this, _getPrototypeOf(EditRoleAssignmentsManagementToolbarDefaultEventHandler).apply(this, arguments));
    }

    _createClass(EditRoleAssignmentsManagementToolbarDefaultEventHandler, [{
      key: "addSegmentEntry",
      value: function addSegmentEntry(itemData) {
        window.sessionStorage.setItem(itemData.sessionKey, 'open');
        Liferay.Util.getTop().location.href = itemData.addSegmentEntryURL;
      }
    }]);

    return EditRoleAssignmentsManagementToolbarDefaultEventHandler;
  }(_frontendJsWeb.DefaultEventHandler);

  var _default = EditRoleAssignmentsManagementToolbarDefaultEventHandler;
  exports["default"] = _default;
  //# sourceMappingURL=EditRoleAssignmentsManagementToolbarDefaultEventHandler.es.js.map
});
//# sourceMappingURL=EditRoleAssignmentsManagementToolbarDefaultEventHandler.es.js.map
